Class: Moov::Models::Components::AdjustmentFees Deprecated
- Inherits:
-
Object
- Object
- Moov::Models::Components::AdjustmentFees
- Extended by:
- T::Sig
- Includes:
- Crystalline::MetadataFields
- Defined in:
- lib/moov/models/components/adjustmentfees.rb
Overview
Deprecated.
class: This will be removed in a future release, please migrate away from it as soon as possible.
The total amount of adjustment fees. This field is deprecated and will be removed in a future release.
Instance Method Summary collapse
- #==(other) ⇒ Object
-
#initialize(currency:, value_decimal:) ⇒ AdjustmentFees
constructor
A new instance of AdjustmentFees.
Methods included from Crystalline::MetadataFields
#field, #fields, included, #marshal_single, #to_dict, #to_json
Constructor Details
#initialize(currency:, value_decimal:) ⇒ AdjustmentFees
Returns a new instance of AdjustmentFees.
25 26 27 28 |
# File 'lib/moov/models/components/adjustmentfees.rb', line 25 def initialize(currency:, value_decimal:) @currency = currency @value_decimal = value_decimal end |
Instance Method Details
#==(other) ⇒ Object
31 32 33 34 35 36 |
# File 'lib/moov/models/components/adjustmentfees.rb', line 31 def ==(other) return false unless other.is_a? self.class return false unless @currency == other.currency return false unless @value_decimal == other.value_decimal true end |