Class: Moov::Models::Components::CreateRefund

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Includes:
Crystalline::MetadataFields
Defined in:
lib/moov/models/components/createrefund.rb

Overview

Specifies a partial amount to refund.

This request body is optional, an empty body will issue a refund for the full amount of the original transfer.

Instance Method Summary collapse

Methods included from Crystalline::MetadataFields

#field, #fields, included, #marshal_single, #to_dict, #to_json

Constructor Details

#initialize(amount: nil, amount_details: nil) ⇒ CreateRefund

Returns a new instance of CreateRefund.



23
24
25
26
# File 'lib/moov/models/components/createrefund.rb', line 23

def initialize(amount: nil, amount_details: nil)
  @amount = amount
  @amount_details = amount_details
end

Instance Method Details

#==(other) ⇒ Object



29
30
31
32
33
34
# File 'lib/moov/models/components/createrefund.rb', line 29

def ==(other)
  return false unless other.is_a? self.class
  return false unless @amount == other.amount
  return false unless @amount_details == other.amount_details
  true
end