Class: Moov::Models::Components::MXAuthorizationCode

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Includes:
Crystalline::MetadataFields
Defined in:
lib/moov/models/components/mxauthorizationcode.rb

Overview

The authorization code of a MX account which allows a processor to retrieve a linked payment account.

‘sandbox` - When linking a bank account to a `sandbox` account using a MX authorization code it will utilize MX’s sandbox environment. The MX authorization code provided must be generated from MX’s sandbox environment.

Instance Method Summary collapse

Methods included from Crystalline::MetadataFields

#field, #fields, included, #marshal_single, #to_dict, #to_json

Constructor Details

#initialize(authorization_code:) ⇒ MXAuthorizationCode

Returns a new instance of MXAuthorizationCode.



22
23
24
# File 'lib/moov/models/components/mxauthorizationcode.rb', line 22

def initialize(authorization_code:)
  @authorization_code = authorization_code
end

Instance Method Details

#==(other) ⇒ Object



27
28
29
30
31
# File 'lib/moov/models/components/mxauthorizationcode.rb', line 27

def ==(other)
  return false unless other.is_a? self.class
  return false unless @authorization_code == other.authorization_code
  true
end