Class: Moov::Models::Components::OtherFees Deprecated

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Includes:
Crystalline::MetadataFields
Defined in:
lib/moov/models/components/otherfees.rb

Overview

Deprecated.

class: This will be removed in a future release, please migrate away from it as soon as possible.

The total amount of other card fees. This field is deprecated and will be removed in a future release. Use summary.otherCardFees.

Instance Method Summary collapse

Methods included from Crystalline::MetadataFields

#field, #fields, included, #marshal_single, #to_dict, #to_json

Constructor Details

#initialize(currency:, value_decimal:) ⇒ OtherFees

Returns a new instance of OtherFees.



25
26
27
28
# File 'lib/moov/models/components/otherfees.rb', line 25

def initialize(currency:, value_decimal:)
  @currency = currency
  @value_decimal = value_decimal
end

Instance Method Details

#==(other) ⇒ Object



31
32
33
34
35
36
# File 'lib/moov/models/components/otherfees.rb', line 31

def ==(other)
  return false unless other.is_a? self.class
  return false unless @currency == other.currency
  return false unless @value_decimal == other.value_decimal
  true
end