Class: Moov::Models::Components::PaymentLinkCustomAmountPaymentDetails
- Inherits:
-
Object
- Object
- Moov::Models::Components::PaymentLinkCustomAmountPaymentDetails
- Extended by:
- T::Sig
- Includes:
- Crystalline::MetadataFields
- Defined in:
- lib/moov/models/components/paymentlinkcustomamountpaymentdetails.rb
Overview
Options for custom amount payment links.
A custom amount payment link shares all the options of a ‘payment` link, but the payor chooses how much to pay rather than the merchant fixing the amount. The amount may optionally be constrained to a range.
Instance Method Summary collapse
- #==(other) ⇒ Object
-
#initialize(allowed_methods:, card_details: nil, ach_details: nil, metadata: nil, amount_range: nil, suggested_amounts: nil) ⇒ PaymentLinkCustomAmountPaymentDetails
constructor
A new instance of PaymentLinkCustomAmountPaymentDetails.
Methods included from Crystalline::MetadataFields
#field, #fields, included, #marshal_single, #to_dict, #to_json
Constructor Details
#initialize(allowed_methods:, card_details: nil, ach_details: nil, metadata: nil, amount_range: nil, suggested_amounts: nil) ⇒ PaymentLinkCustomAmountPaymentDetails
Returns a new instance of PaymentLinkCustomAmountPaymentDetails.
36 37 38 39 40 41 42 43 |
# File 'lib/moov/models/components/paymentlinkcustomamountpaymentdetails.rb', line 36 def initialize(allowed_methods:, card_details: nil, ach_details: nil, metadata: nil, amount_range: nil, suggested_amounts: nil) @allowed_methods = allowed_methods @card_details = card_details @ach_details = ach_details @metadata = @amount_range = amount_range @suggested_amounts = suggested_amounts end |
Instance Method Details
#==(other) ⇒ Object
46 47 48 49 50 51 52 53 54 55 |
# File 'lib/moov/models/components/paymentlinkcustomamountpaymentdetails.rb', line 46 def ==(other) return false unless other.is_a? self.class return false unless @allowed_methods == other.allowed_methods return false unless @card_details == other.card_details return false unless @ach_details == other.ach_details return false unless @metadata == other. return false unless @amount_range == other.amount_range return false unless @suggested_amounts == other.suggested_amounts true end |