Class: Moov::Models::Components::PaymentLinkPaymentDetailsAmountType

Inherits:
T::Enum
  • Object
show all
Defined in:
lib/moov/models/components/paymentlinkpaymentdetails_amounttype.rb

Overview

PaymentLinkPaymentDetailsAmountType - Indicates whether the payment amount is fixed by the merchant or open for the buyer to choose.