Class: Moov::Models::Components::PaymentLinkPaymentDetailsUpdateAmountType

Inherits:
T::Enum
  • Object
show all
Defined in:
lib/moov/models/components/paymentlinkpaymentdetailsupdate_amounttype.rb

Overview

PaymentLinkPaymentDetailsUpdateAmountType - Indicates whether the payment amount is fixed by the merchant or open for the buyer to choose.