Class: Moov::Models::Components::PlaidLinkIntegration

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Includes:
Crystalline::MetadataFields
Defined in:
lib/moov/models/components/plaidlinkintegration.rb

Overview

This is used by Moov.js with a Plaid reseller relationship. The details of a Plaid link integration for a linked funding source.

You can simulate linking bank accounts with Plaid in test mode. See our test mode guide for more information.

Plaid's sandbox environment - (requires Plaid reseller setup with Moov). When linking a bank account to a sandbox account using a Plaid public token it will utilize Plaid's sandbox environment. The Plaid public token provided must be generated from Plaid's sandbox environment. Please see Plaid's sandbox documentation for more details.

Instance Method Summary collapse

Methods included from Crystalline::MetadataFields

#field, #fields, included, #marshal_single, #to_dict, #to_json

Constructor Details

#initialize(public_token:) ⇒ PlaidLinkIntegration

Returns a new instance of PlaidLinkIntegration.



27
28
29
# File 'lib/moov/models/components/plaidlinkintegration.rb', line 27

def initialize(public_token:)
  @public_token = public_token
end

Instance Method Details

#==(other) ⇒ Object



32
33
34
35
36
# File 'lib/moov/models/components/plaidlinkintegration.rb', line 32

def ==(other)
  return false unless other.is_a? self.class
  return false unless @public_token == other.public_token
  true
end