Class: Moov::Models::Components::PlatformFees Deprecated

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Includes:
Crystalline::MetadataFields
Defined in:
lib/moov/models/components/platformfees.rb

Overview

Deprecated.

class: This will be removed in a future release, please migrate away from it as soon as possible.

A detailed breakdown of platform fees. This field is deprecated and will be removed in a future release. Use accountFees.

Instance Method Summary collapse

Methods included from Crystalline::MetadataFields

#field, #fields, included, #marshal_single, #to_dict, #to_json

Constructor Details

#initialize(wallet_fee:, merchant_pci_fee:, total:) ⇒ PlatformFees

Returns a new instance of PlatformFees.



25
26
27
28
29
# File 'lib/moov/models/components/platformfees.rb', line 25

def initialize(wallet_fee:, merchant_pci_fee:, total:)
  @wallet_fee = wallet_fee
  @merchant_pci_fee = merchant_pci_fee
  @total = total
end

Instance Method Details

#==(other) ⇒ Object



32
33
34
35
36
37
38
# File 'lib/moov/models/components/platformfees.rb', line 32

def ==(other)
  return false unless other.is_a? self.class
  return false unless @wallet_fee == other.wallet_fee
  return false unless @merchant_pci_fee == other.merchant_pci_fee
  return false unless @total == other.total
  true
end