Class: Moov::Models::Components::UpdateIssuedCardState

Inherits:
T::Enum
  • Object
show all
Defined in:
lib/moov/models/components/updateissuedcardstate.rb

Overview

UpdateIssuedCardState - Updates the state of a Moov issued card.

  • ‘closed`: The card is permanently deactivated and cannot approve authorizations. A card can be closed by request or when it expires.