Class: Moov::Models::Components::VerificationStatus Deprecated

Inherits:
T::Enum
  • Object
show all
Defined in:
lib/moov/models/components/verificationstatus.rb

Overview

Deprecated.

class: This will be removed in a future release, please migrate away from it as soon as possible.

VerificationStatus - Possible states an account verification can be in.