Class: Moov::Models::Components::WalletStatus

Inherits:
T::Enum
  • Object
show all
Defined in:
lib/moov/models/components/walletstatus.rb

Overview

WalletStatus - Status of a wallet.

  • active: The wallet is available for use and has an enabled payment method.
  • closed: The wallet is no longer active and the corresponding payment method has been disabled.