Class: Moov::Models::Components::CapabilityID

Inherits:
T::Enum
  • Object
show all
Defined in:
lib/moov/models/components/capabilityid.rb

Overview

CapabilityID - Moov account capabilities.

**Deprecated capabilities**

The ‘send-funds`, `collect-funds`, and `wallet` capability IDs are deprecated. Request granular capabilities instead (for example, `send-funds.ach`, `collect-funds.card-payments`, or `wallet.balance`). Deprecated values will be removed in a future API version.

Read our [capabilities reference](docs.moov.io/guides/accounts/capabilities/reference/) to choose the right capabilities for your integration.

The ‘production-app`, `platform.production-app`, and / or `platform.wallet-transfers` capabilities might appear in the list for your Partner account. These are read-only capabilities that Moov requests. These capabilities remain active with your account and require no additional action.