Class: Moov::Models::Components::IssuedCardState
- Inherits:
-
T::Enum
- Object
- T::Enum
- Moov::Models::Components::IssuedCardState
- Defined in:
- lib/moov/models/components/issuedcardstate.rb
Overview
IssuedCardState - The state represents the operational status of an issued card. A card can only approve incoming authorizations if it is in an active state.
active: The card is operational and can approve authorizations.closed: The card is permanently deactivated and cannot approve authorizations. A card can be closed by request or when it expires.