Class: Moov::Models::Components::TipCalculationBasis

Inherits:
T::Enum
  • Object
show all
Defined in:
lib/moov/models/components/tipcalculationbasis.rb

Overview

TipCalculationBasis - Defines which amount should be used when calculating the final payment total. This calculation applies for percentage tip values.

  • ‘pre-tax`: Tip amounts are calculated using the subtotal amount before taxes

  • ‘post-tax`: Tip amounts are calculated using the subtotal amount + taxes